pub struct Join {
pub kind: JoinKind,
pub table: TableRef,
pub on: Option<Expr>,
pub natural: bool,
pub using: Vec<String>,
}Expand description
A join onto a table.
Fields
kind: JoinKindThe kind of join.
table: TableRefThe joined table.
on: Option<Expr>An ON predicate, if present.
natural: boolNATURAL join: join on equality of all columns common to both sides
(mutually exclusive with on/using).
using: Vec<String>USING (col, …): join on equality of the named columns, which are then
coalesced into a single output column each (mutually exclusive with on).