Connection

Struct Connection 

pub struct Connection { /* private fields */ }
A database connection. Supports reading (query) and writing (execute), over a file or in memory.

Implementations

Source

impl Connection

pub fn open_vfs(vfs: &dyn Vfs, path: &str) -> Result<Connection>

Open an existing database for reading and writing through vfs. Creates (and recovers from) a <path>-journal companion file.

pub fn open_readonly_vfs(vfs: &dyn Vfs, path: &str) -> Result<Connection>

Open an existing database read-only through vfs. If a <path>-wal file is present, its committed frames are overlaid so WAL-mode databases read correctly.

pub fn create_vfs( vfs: &dyn Vfs, path: &str, page_size: u32, ) -> Result<Connection>

Create a new, empty database through vfs.

pub fn open(path: &str) -> Result<Connection>

Available on crate feature std only.

Open an existing database file for reading and writing (requires std).

pub fn open_readonly(path: &str) -> Result<Connection>

Available on crate feature std only.

Open an existing database file read-only (requires std).

pub fn create(path: &str) -> Result<Connection>

Available on crate feature std only.

Create a new database file with the default 4096-byte page size (std).

pub fn open_memory() -> Result<Connection>

Create a fresh in-memory database (:memory:), always available.

pub fn schema(&self) -> &Schema

The schema catalog.

pub fn query(&self, sql: &str) -> Result<QueryResult>

Run a single SELECT and return all rows.

pub fn query_params(&self, sql: &str, params: &Params) -> Result<QueryResult>

Like query but with bound parameters.

pub fn execute(&mut self, sql: &str) -> Result<usize>

Execute a single non-SELECT statement, returning the number of rows affected (0 for DDL and transaction control).

pub fn execute_params(&mut self, sql: &str, params: &Params) -> Result<usize>

Like execute but with bound parameters.